 #!/usr/bin/env python3
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   Copyright (C) 2022 SVA System Vertrieb Alexander GmbH
#                       by michael.hoess@sva.de

from typing import Tuple
from cmk.gui.i18n import _              

from cmk.gui.plugins.wato.utils import (    
    rulespec_registry, 
    CheckParameterRulespecWithItem,        
    RulespecGroupCheckParametersEnvironment,
)

from cmk.gui.valuespec import (
    Dictionary,    
    Integer,
    Float,
    Tuple,
    TextAscii,
)

#
# Temperature
#


def _item_valuespec_akcp_sensors_temp():
    return TextAscii(title=_("Sensor name"))



def _vs_akcp_sensors_temperature():
    return Dictionary(                    
        title="Thresholds, overriding those defined on device",        
        help="If nothing is defined below, thresholds defined on device are used",
        elements=[
            ("levels_lower", Tuple(
                title=_("Lower levels"),
                elements = [
                    Float(
                        title = _("Warning at"),
                        default_value = 10,
                    ),
                    Float(
                        title = _("Critical at"),
                        default_value = 5,
                    )
                ])),
            ("levels_upper", Tuple(
                title=_("Upper levels"),
                elements = [
                    Float(
                        title = _("Warning at"),
                        default_value = 40,
                    ),
                    Float(
                        title = _("Critical at"),
                        default_value = 50,
                    )
                ]))            
        ], 
    )


rulespec_registry.register(                                    
    CheckParameterRulespecWithItem(
        check_group_name="check_akcp_sensors_temperature",
        group=RulespecGroupCheckParametersEnvironment,
        match_type="dict",
        item_spec=_item_valuespec_akcp_sensors_temp,
        parameter_valuespec=_vs_akcp_sensors_temperature,
        title=lambda: _("AKCP sensors temperature thresholds"),
    )
)


#
# Humidity
#



def _item_valuespec_akcp_sensors_humi():
    return TextAscii(title=_("Sensor name"))



def _vs_akcp_sensors_humi():
    return Dictionary(                    
        title="Thresholds, overriding those defined on device",        
        help="If nothing is defined below, thresholds defined on device are used. Value are specific for sensor types. "
                +"e.g. °C for temperature sensors or % for humidity",
        elements=[
            ("levels_lower", Tuple(
                title=_("Lower levels"),
                elements = [
                    Integer(
                        title = _("Warning at"),
                        default_value = 20,
                    ),
                    Integer(
                        title = _("Critical at"),
                        default_value = 10,
                    )
                ])),
            ("levels_upper", Tuple(
                title=_("Upper levels"),
                elements = [
                    Integer(
                        title = _("Warning at"),
                        default_value = 80,
                    ),
                    Integer(
                        title = _("Critical at"),
                        default_value = 90,
                    )
                ]))            
        ], 
    )


rulespec_registry.register(                                    
    CheckParameterRulespecWithItem(
        check_group_name="check_akcp_sensors_humidity",
        group=RulespecGroupCheckParametersEnvironment,
        match_type="dict",
        item_spec=_item_valuespec_akcp_sensors_humi,
        parameter_valuespec=_vs_akcp_sensors_humi,
        title=lambda: _("AKCP sensors humidity thresholds"),
    )
)
